@@ -6,6 +6,6 @@ use warnings;
 use strict;
 
 # The Internet King? I wonder if he could provide faster nudity...
-use base 'LoaderTestBase';
+use base 'Mojo::Base';
 
 1;
